<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="cs" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategorie:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Spustit torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Přeskočit kontrolu hashe</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Vytvořit podsložku</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Režim správy torrentu:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Nezařazeno</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Přidat kategorii...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Odstranit kategorii</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Odstranit nevyužité kategorie</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Obnovit torrenty</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Pozastavit torrenty</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Smazat torrenty</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nová kategorie</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Editovat kategorii...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Ukončit qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Pouze jeden odkaz na řádek</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Globální limit odesílání musí být větší než 0 nebo vypnut.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Globální limit stahování musí být větší než 0 nebo vypnut.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Alternativní limit odesílání musí být větší než 0 nebo vypnut.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Alternativní limit stahování musí být větší než 0 nebo vypnut.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Maximum aktivních stahování musí být větší než -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Maximum aktivních odesílání musí být větší než -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Maximum aktivních torrentů musí být větší než -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Maximální počet spojení musí být větší než 0 nebo vypnut.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Maximální počet spojení na torrent musí být větší než 0 nebo vypnut.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Limit maximálního počtu slotů na torrent musí být větší než 0 nebo vypnut.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Nelze uložit nastavení programu, qBittorrent klient je pravděpodobně nedostupný.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent na Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Limit ratia musí být v rozsahu od 0 do 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Doba seedování musí být v rozsahu od 0 do 525600 minut.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Port příchozích spojení musí být mezi 1 a 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Port webového rozhraní musí být mezi 1 a 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Nelze se přihlásit, qBittorrent je pravděpodobně nedostupný</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Neplatné jméno nebo heslo</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Přihlášení</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Původní autoři</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Použít</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Nahrát torrenty</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Ukládat soubory do umístění:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Zadejte název adresáře</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Více informací</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Informace o certifikátech</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Nastavit umístění</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Omezit rychlost odesílání</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Omezit rychlost stahování</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Přejmenovat torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Jiná...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Pondělí</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Úterý</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Středa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Čtvrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Pátek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Neděle</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odhlásit</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Stahovat torrenty z jejich URL nebo Magnet linku</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Nahrát lokální torrent</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Opravdu chcete smazat vybrané torrenty ze seznamu přenosů?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Klient qBittorrent není dostupný</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Celkový počet nahrávacích slotů musí být větší než 0 nebo být vypnutý.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Neplatný název kategorie:\nProsím nepoužívejte žádné speciální znaky ani diakritiku v názvu kategorie.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Nelze vytvořit kategorii</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Limit odesílání musí být větší než 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Volné místo : %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Časovač nečinnosti torrentu musí být větší než 0:</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Správa ukládání</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>Limit rychlosti stahování musí být větší než 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent byl ukončen</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Úpravy</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Nástroje</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Možnosti...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Minimální priorita</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Top priorita</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Snížit prioritu</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Zvýšit prioritu</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Horní panel nástrojů</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Stavová lišta</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Rychlost v záhlaví okna</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Darujte!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Obnovit vše</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Pozastavit vše</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Přidat torrent soubor...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentace</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Přidat torrent link...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Celkový limit rychlosti odesílání</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Celkový limit rychlosti stahování</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Určitě chcete ukončit qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[S: %1, O: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Alternativní limity rychlosti</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Vyhledávač</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtrovat seznam torrentů...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Přenosy</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Připojení</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Rychlost</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Web UI</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Jazyk uživatelského rozhraní:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Upozornění emailem při dokončení stahování</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Spustit externí program při dokončení stažení torrentu</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Filtrování IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Plánovat použití alternativních omezení rychlosti</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Řazení torrentů do fronty</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Odesílat torrenty dokud není dosaženo jejich časového limitu</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Automaticky přidat tyto trackery k novým stahováním:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Webové uživatelské rozhraní (vzdálená správa)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP adresa:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Domény serveru:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Použít HTTPS místo HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Přeskočit ověření klientů na místní síti</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Přeskočit ověření klientů na seznamu povolených IP podsítí</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Aktualizovat můj dynamický doménový název (DDNS)</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Ponechat nedokončené torrenty v:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Kopírovat .torrent soubory do:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Kopírovat .torrent soubory dokončených stahování do:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Předem vyhradit místo na disku pro všechny soubory</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Přidat příponu .!qB k nedokončeným souborům</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Automaticky přidávat .torrent soubory z:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP server:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Tento server vyžaduje zabezpečené připojení (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Ověření</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uživatelské jméno:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Zapnout protokol:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP a μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Naslouchací port</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Port použitý pro příchozí spojení:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Použít přesměrování portů UPnP / NAT-PMP z mého routeru</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Při každém spuštění použít náhodné porty</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Limit spojení</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Maximální počet spojení na torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Celkový maximální počet spojení:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Maximální počet odesílacích slotů na torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Celkový maximální počet odesílacích slotů:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Proxy server</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(žádný)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Použít proxy pro připojení k protějškům</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Zakázat připojení nepodporovaná připojením proxy</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Použít proxy pouze pro torrenty</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Cesta k filtru (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Seznam ručně zakázaných IP adres...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Použít pro trackery</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Celkové limity rychlosti</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Odesílání:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Stahování:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Alternativní limity rychlosti</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Od:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Do:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Kdy:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Každý den</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Pracovní dny</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Víkendy</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Nastavení poměru sdílení</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Použít limity rychlosti pro režijní provoz</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Použít omezení rychlosti pro uTP připojení</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Soukromí</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Zapnout DHT síť (decentralizovaná síť) k nalezení většího počtu protějšků</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Zapnout Peer Exchange (PeX) k nalezení většího počtu protějšků</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Zapnout místní vyhledávání k nalezení většího počtu protějšků</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Režim šifrování:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Upřednostnit šifrování</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Vyžadovat šifrování</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Vypnout šifrování</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Povolit anonymní režim</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Max. počet aktivních stahování:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Max. počet aktivních odesílání:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Maximální počet aktivních torrentů:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Nezapočítávat pomalé torrenty do těchto limitů</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Omezení ratia</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Sdílet torrenty dokud ratio nedosáhne</translation>
    </message>
    <message>
        <source>then</source>
        <translation>potom</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Pozastavit je</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Odstranit je</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Použít UPnP / NAT-PMP k přesměrování portu z mého routeru</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certifikát:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Klíč:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registrovat</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Doména:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Podporované parametry (citlivé na velikost znaků):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Název torrentu</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategorie</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="vanished">%G: Štítky (oddělené čárkou)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Umístění obsahu (stejné jako zdrojová cesta u vícesouborového torrentu)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Zdrojová cesta (první podadresář torrentu)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Cesta pro uložení</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Počet souborů</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Velikost torrentu (v bytech)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Současný tracker</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Info hash</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Tip: Ohraničit parametr uvozovkami, aby nedošlo k odstřižení textu za mezerou (např. "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Uživatelské jméno pro webové rozhraní musí být nejméně 3 znaky dlouhé.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Heslo pro webové rozhraní musí být nejméně 6 znaků dlouhé.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuty</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Aktivujte ochranu clickjacking</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Zapnout ochranu  Cross-Site Request Forgery (CSRF)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Následně smazat .torrent soubory</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Limit rychlosti stahování:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Limit rychlosti odesílání:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Změnit současné heslo</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatický</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Použít alternativní Web UI</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Výchozí cesta pro uložení:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Umístění souborů Alternativního UI nemůže být prázdné.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Nespouštět stahování automaticky</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Přepnout torrent do ručního módu</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Když je kategorie torrentu změněna:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Přemístit dotčené torrenty</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Omezit poměr sdílení protějškům na LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 znamená neomezeno</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Přemístit torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Při změně výchozí cesty pro uložení:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Zapnout ověřování hlavičky hostitele</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Bezpečnost</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Při změně cesty pro uložení Kategorií:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Vytvořit podadresář pro torrent s více soubory</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekundy</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Přepnout dotčené torrenty do ručního módu</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Umístění souborů:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuální</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Časovač nečinnosti torrentu:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Výchozí režim správy torrentu:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Při přidání torrentu</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Vlajky</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Připojení</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Průběh</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Rychlost stahování</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Rychlost odesílání</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Staženo</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Odesláno</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Důležitost</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Soubory</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Země</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normální</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Vysoká</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Maximální</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Trackery</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Protějšky</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP zdroje</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Obsah</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Staženo:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Přenos</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Aktivní po dobu:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Odh. čas:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Odesláno:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Zdroje:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Rychlost stahování:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Rychlost odesílání:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Protějšky:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Omezení stahování:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Omezení odesílání:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Zahozeno:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Připojení:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informace</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Komentář:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Poměr sdílení:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Znovu-oznámit za:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Poslední komplet zdroj:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Celková velikost:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Části:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Vytvořil/a:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Přidáno:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Dokončeno:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Vytvořeno:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Kontrolní součet:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Uložit do:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (má %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 toto sezení)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 max)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 celkem)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 prům.)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Omezení stahování:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Omezení odesílání:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Sledovaný adresář</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Přepsat umístění pro uložení</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Sledovaný adresář</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Výchozí umístění pro uložení:</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Statistiky uživatele</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Statistiky vyrovnávací paměti</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Přístupy do cache pro čtení:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Průměrná doba ve frontě:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Připojení peerové:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Celkový poměr sdílení:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Celkově staženo:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Zahozeno od spuštění:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Celkově odesláno:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Celková velikost vyrovnávací paměti:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Statistiky výkonu</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>I/O úkoly ve frontě:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Přeplnění cache pro zápis:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Přetížení cache pro čtení:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Celková velikost fronty:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 uzlů</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Vše (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Stahuji (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Sdílím (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Dokončeno (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Obnoveno (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Pozastaveno (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Aktivní (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Neaktivní (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>S chybou (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Vše (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Stahuji (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Sdílím (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Dokončeno (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Pozastaveno (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Obnoveno (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Aktivní (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Neaktivní (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>S chybou (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Průběh</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Priorita stahování</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Zbývající</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Dostupnost</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Název</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Velikost</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Hotovo</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Zdroje</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Protějšky</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Rychlost stahování</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Rychlost odesílání</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Ratio</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Odh. čas</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Štítky</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Přidán</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Dokončen</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Limit stahování</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Limit odesílání</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Staženo</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Odesláno</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Staženo po spuštění</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Odesláno po spuštění</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Zbývající</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Aktivní po dobu</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Cesta pro uložení</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Dokončeno</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Omezení ratia</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Poslední komplet zdroj</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Poslední aktivita</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Celková velikost</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Protějšky</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Zpráva</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Staženo</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>URL trackeru:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Aktualizuji...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Funkční</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Zakázáno</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Dosud nekontaktován</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>není k dispozici</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Seedy</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Nefunkční</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Kopírovat URL trackeru</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Přidat nový tracker...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Upravit URL trackeru</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Upravit tracker</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Leeches</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Odstranit tracker</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Dialog pro přidání trackeru</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Seznam trackerů pro přidání (jeden na řádek):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>před %1</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Přiděluji místo</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pozastaveno</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Dokončeno</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Přesouvám</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Sdílím</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Sdíleno</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Zařazeno do fronty</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>S chybou</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Stahuji</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Stahuji metadata</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Kontroluji</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Chybějící soubory</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Ve frontě na kontrolu</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Stahuji</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Kontrola dat pro obnovení</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Pozastaveno</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorie</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Limit rychlosti stahování torrentu</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Limit rychlosti odesílání torrentu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Obnovit</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Vynutit obnovení</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Omezit ratio...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Omezit rychlost odesílání...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Omezit rychlost stahování...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Přesunout nahoru</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Přesunout dolů</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Přesunout na začátek</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Přesunout na konec</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Nastavit umístění...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Kopírovat název</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Zkopírovat hash</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Stáhnout nejdříve první a poslední část</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Automatická správa torrentu</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Nový...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Resetovat</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorita</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Vynutit překontrolování</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Kopírovat Magnet link</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Mód super sdílení</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Přejmenovat...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Stahovat postupně</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Vynutit překontrolování</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nová kategorie</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Nový název</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Nastavit umístění</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Vynutit oznámení</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Upravit kategorii</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Cesta pro uložení</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Omezení ratia pro odesílání/stahování torrentu</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Nastavení globálního limitu sdílení</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Nastavit sdílení bez limitu</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Nastavit limit sdílení na</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>ratio</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuty</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Pokročilý BitTorrent klient naprogramován v jazyce C++, založený na Qt toolkit a libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Domovská stránka:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Fórum:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Sledování chyb:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Potvrzení o smazání</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Smazat soubory také z pevného disku</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Potvrzení o smazání - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Stahovat z URL</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Stahovat</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Přidat odkazy torrentů</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1h %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1d %2h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Neznámá</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Cesta pro uložení je prázdná</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Cesta k pluginu:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL nebo místní složka</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Instalovat plugin</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Seedy:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Všechny pluginy</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Pluginy pro vyhledávání</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Všechny kategorie</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Hledat v:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Kopírovat URL stránky s popisem</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Přejít na stránku s popisem</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Výsledky (zobrazuji</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Stáhnout</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Pouze názvy torrentů</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Pouze zapnuté</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>mimo</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Všude</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Odinstalovat</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Instalovat nový plugin</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Nové vyhledávací pluginy můžete získat zde:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Nainstalované vyhledávací pluginy:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Zapnuto</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Varování: Ujistěte se, že dodržujete zákony Vaší země o ochraně duševního vlastnictví když stahujete torrenty z kteréhokoliv z těchto vyhledávačů.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Zkontrolovat aktualizace</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Pluginy pro vyhledávání</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Leecheři</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Vyhledávač</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Seedeři</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Zapnuto</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
</context>
</TS>